@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -31,15 +31,15 @@ import net.sf.ehcache.management.sampled.SampledCacheManager;
 
 /**
  * Implementation of {@link EhcacheStats}
- * 
+ *
  * <p />
- * 
+ *
  * @author <a href="mailto:asanoujam@terracottatech.com">Abhishek Sanoujam</a>
- * 
+ *
  */
 public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
     private static final long MILLIS_PER_SECOND = 1000;
-    private static final MBeanNotificationInfo[] NOTIFICATION_INFO;
+    private static final MBeanNotificationInfo NOTIFICATION_INFO;
 
     private final SampledCacheManager sampledCacheManager;
     private final CacheManager cacheManager;
@@ -50,12 +50,12 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
                 CACHE_STATISTICS_ENABLED, CACHE_STATISTICS_RESET, };
         final String name = Notification.class.getName();
         final String description = "Ehcache Hibernate Statistics Event";
-        NOTIFICATION_INFO = new MBeanNotificationInfo[] {new MBeanNotificationInfo(notifTypes, name, description), };
+        NOTIFICATION_INFO = new MBeanNotificationInfo(notifTypes, name, description);
     }
 
     /**
      * Constructor accepting the backing {@link CacheManager}
-     * @throws NotCompliantMBeanException 
+     * @throws NotCompliantMBeanException
      */
     public EhcacheStatsImpl(CacheManager manager) throws NotCompliantMBeanException {
         super(EhcacheStats.class);
@@ -310,10 +310,10 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
      */
     public int getRegionCacheOrphanEvictionPeriod(String region) {
         Cache cache = this.cacheManager.getCache(region);
-        if (cache == null) {
-            return -1;
+        if (cache != null && cache.isTerracottaClustered()) {
+          return cache.getCacheConfiguration().getTerracottaConfiguration().getOrphanEvictionPeriod();
         } else {
-            return cache.getCacheConfiguration().getTerracottaConfiguration().getOrphanEvictionPeriod();
+          return -1;
         }
     }
 
@@ -326,7 +326,8 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
             Cache cache = cacheManager.getCache(name);
             if (cache != null) {
                 rv.put(name, new int[] {(int) cache.getSampledCacheStatistics().getCacheHitMostRecentSample(),
-                        (int) cache.getSampledCacheStatistics().getCacheMissMostRecentSample(),
+                        (int) (cache.getSampledCacheStatistics().getCacheMissNotFoundMostRecentSample()
+                                + cache.getSampledCacheStatistics().getCacheMissExpiredMostRecentSample()),
                         (int) cache.getSampledCacheStatistics().getCacheElementPutMostRecentSample(), });
             }
         }
@@ -441,7 +442,7 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
      */
     public boolean isRegionCacheOrphanEvictionEnabled(String region) {
         Cache cache = this.cacheManager.getCache(region);
-        if (cache != null) {
+        if (cache != null && cache.isTerracottaClustered()) {
             return cache.getCacheConfiguration().getTerracottaConfiguration().getOrphanEviction();
         } else {
             return false;
@@ -517,7 +518,7 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
 
     /**
      * {@inheritDoc}
-     * 
+     *
      * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getNumberOfElementsInMemory(java.lang.String)
      */
     public int getNumberOfElementsInMemory(String region) {
@@ -531,7 +532,21 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
 
     /**
      * {@inheritDoc}
-     * 
+     *
+     * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getNumberOfElementsOffHeap(java.lang.String)
+     */
+    public int getNumberOfElementsOffHeap(String region) {
+        Cache cache = this.cacheManager.getCache(region);
+        if (cache != null) {
+            return (int) cache.getOffHeapStoreSize();
+        } else {
+            return -1;
+        }
+    }
+
+    /**
+     * {@inheritDoc}
+     *
      * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getNumberOfElementsOnDisk(java.lang.String)
      */
     public int getNumberOfElementsOnDisk(String region) {
@@ -589,7 +604,7 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
 
     /**
      * {@inheritDoc}
-     * 
+     *
      * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getMaxGetTimeMillis(java.lang.String)
      */
     public long getMaxGetTimeMillis(String cacheName) {
@@ -603,7 +618,7 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
 
     /**
      * {@inheritDoc}
-     * 
+     *
      * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getMinGetTimeMillis(java.lang.String)
      */
     public long getMinGetTimeMillis(String cacheName) {
@@ -617,7 +632,7 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
 
     /**
      * {@inheritDoc}
-     * 
+     *
      * @see net.sf.ehcache.hibernate.management.api.EhcacheStats#getAverageGetTimeMillis(java.lang.String)
      */
     public float getAverageGetTimeMillis(String region) {
@@ -629,11 +644,19 @@ public class EhcacheStatsImpl extends BaseEmitterBean implements EhcacheStats {
         }
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    protected void doDispose() {
+        // no-op
+    }
+
     /**
      * @see BaseEmitterBean#getNotificationInfo()
      */
     @Override
     public MBeanNotificationInfo[] getNotificationInfo() {
-        return NOTIFICATION_INFO;
+        return new MBeanNotificationInfo[]{NOTIFICATION_INFO};
     }
 }
