@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -50,6 +50,7 @@ import net.sf.ehcache.CacheException;
 import net.sf.ehcache.CacheManager;
 import net.sf.ehcache.Ehcache;
 import net.sf.ehcache.bootstrap.BootstrapCacheLoader;
+import net.sf.ehcache.config.PersistenceConfiguration.Strategy;
 import net.sf.ehcache.config.TerracottaConfiguration.Consistency;
 import net.sf.ehcache.distribution.CacheManagerPeerListener;
 import net.sf.ehcache.distribution.CacheManagerPeerProvider;
@@ -82,7 +83,7 @@ import org.slf4j.LoggerFactory;
  * in the classpath.
  *
  * @author <a href="mailto:gluck@thoughtworks.com">Greg Luck</a>
- * @version $Id: ConfigurationFactoryTest.java 4748 2011-09-27 15:58:15Z lorban $
+ * @version $Id: ConfigurationFactoryTest.java 6485 2012-10-27 04:33:18Z cschanck $
  */
 public class ConfigurationFactoryTest extends AbstractCacheTest {
     private static final int CACHES_IN_TEST_EHCACHE = 15;
@@ -254,7 +255,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(false, defaultCache.getCacheConfiguration().isEternal());
         assertEquals(120, defaultCache.getCacheConfiguration().getTimeToIdleSeconds());
         assertEquals(120, defaultCache.getCacheConfiguration().getTimeToLiveSeconds());
-        assertEquals(true, defaultCache.getCacheConfiguration().isOverflowToDisk());
+        assertEquals(Strategy.LOCALTEMPSWAP, defaultCache.getCacheConfiguration().getPersistenceConfiguration().getStrategy());
         assertEquals(10000, defaultCache.getCacheConfiguration().getMaxElementsInMemory());
         assertEquals(10000000, defaultCache.getCacheConfiguration().getMaxElementsOnDisk());
 
@@ -267,7 +268,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(false, sampleCache1Config.isEternal());
         assertEquals(300, sampleCache1Config.getTimeToIdleSeconds());
         assertEquals(600, sampleCache1Config.getTimeToLiveSeconds());
-        assertEquals(true, sampleCache1Config.isOverflowToDisk());
+        assertEquals(Strategy.LOCALTEMPSWAP, sampleCache1Config.getPersistenceConfiguration().getStrategy());
         assertEquals(20, sampleCache1Config.getDiskSpoolBufferSizeMB());
 
         //  <cache name="sampleCache1"
@@ -284,7 +285,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(300, sampleCache1.getCacheConfiguration().getTimeToIdleSeconds());
         assertEquals(1000, sampleCache1.getCacheConfiguration().getMaxElementsOnDisk());
         assertEquals(600, sampleCache1.getCacheConfiguration().getTimeToLiveSeconds());
-        assertEquals(true, sampleCache1.getCacheConfiguration().isOverflowToDisk());
+        assertEquals(Strategy.LOCALTEMPSWAP, sampleCache1Config.getPersistenceConfiguration().getStrategy());
     }
 
     /**
@@ -881,7 +882,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(false, defaultCache.getCacheConfiguration().isEternal());
         assertEquals(120, defaultCache.getCacheConfiguration().getTimeToIdleSeconds());
         assertEquals(120, defaultCache.getCacheConfiguration().getTimeToLiveSeconds());
-        assertEquals(true, defaultCache.getCacheConfiguration().isOverflowToDisk());
+        assertEquals(Strategy.LOCALTEMPSWAP, defaultCache.getCacheConfiguration().getPersistenceConfiguration().getStrategy());
 
         //Check caches
         assertEquals(6, configurationHelper.createCaches().size());
@@ -898,7 +899,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(false, sampleCache1.getCacheConfiguration().isEternal());
         assertEquals(300, sampleCache1.getCacheConfiguration().getTimeToIdleSeconds());
         assertEquals(600, sampleCache1.getCacheConfiguration().getTimeToLiveSeconds());
-        assertEquals(true, sampleCache1.getCacheConfiguration().isOverflowToDisk());
+        assertEquals(Strategy.LOCALTEMPSWAP, sampleCache1.getCacheConfiguration().getPersistenceConfiguration().getStrategy());
     }
 
     /**
@@ -939,7 +940,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
             assertEquals(false, defaultCache.getCacheConfiguration().isEternal());
             assertEquals(120, defaultCache.getCacheConfiguration().getTimeToIdleSeconds());
             assertEquals(120, defaultCache.getCacheConfiguration().getTimeToLiveSeconds());
-            assertEquals(true, defaultCache.getCacheConfiguration().isOverflowToDisk());
+            assertEquals(Strategy.LOCALTEMPSWAP, defaultCache.getCacheConfiguration().getPersistenceConfiguration().getStrategy());
 
             //Check caches
             assertEquals(0, configurationHelper.createCaches().size());
@@ -1146,11 +1147,11 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         ConfigurationHelper configurationHelper = new ConfigurationHelper(manager, configuration);
 
         Ehcache cache = configurationHelper.createCacheFromName("cache");
-        assertTrue(cache.getCacheConfiguration().getElementValueComparatorConfiguration().getElementComparatorInstance(cache.getCacheConfiguration())
+        assertTrue(cache.getCacheConfiguration().getElementValueComparatorConfiguration().createElementComparatorInstance(cache.getCacheConfiguration())
                 instanceof DefaultElementValueComparator);
 
         Ehcache cache2 = configurationHelper.createCacheFromName("cache2");
-        assertTrue(cache2.getCacheConfiguration().getElementValueComparatorConfiguration().getElementComparatorInstance(cache.getCacheConfiguration())
+        assertTrue(cache2.getCacheConfiguration().getElementValueComparatorConfiguration().createElementComparatorInstance(cache.getCacheConfiguration())
                 .getClass().equals(FakeElementValueComparator.class));
     }
 
@@ -1624,7 +1625,7 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         assertEquals(5, config5.getCacheWriterConfiguration().getRateLimitPerSecond());
         assertEquals(true, config5.getCacheWriterConfiguration().getWriteCoalescing());
         assertEquals(false, config5.getCacheWriterConfiguration().getWriteBatching());
-        assertEquals(20, config5.getCacheWriterConfiguration().getWriteBatchSize());
+        assertEquals(1, config5.getCacheWriterConfiguration().getWriteBatchSize());
         assertEquals(2, config5.getCacheWriterConfiguration().getRetryAttempts());
         assertEquals(2, config5.getCacheWriterConfiguration().getRetryAttemptDelaySeconds());
         Ehcache cache5 = configurationHelper.createCacheFromName("writeBehindCache5");
@@ -1684,6 +1685,8 @@ public class ConfigurationFactoryTest extends AbstractCacheTest {
         cacheConfiguration = configuration.getCacheConfigurations().get("offheap2");
         assertEquals(2147483648L, cacheConfiguration.getMaxMemoryOffHeapInBytes());
         assertEquals(false, cacheConfiguration.isOverflowToOffHeap());
+
+        assertEquals(2164260864L, configuration.getTotalConfiguredOffheap());
     }
 
 }
