@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ import net.sf.ehcache.Cache;
 import net.sf.ehcache.CacheException;
 import net.sf.ehcache.CacheManager;
 import net.sf.ehcache.Element;
+import net.sf.ehcache.config.Configuration;
 import net.sf.ehcache.util.RetryAssert;
 
 import org.hamcrest.collection.IsEmptyCollection;
@@ -33,8 +34,11 @@ import static org.hamcrest.core.IsEqual.equalTo;
 import org.junit.Before;
 import org.junit.Test;
 
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.Date;
+import java.util.List;
 import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
@@ -44,7 +48,7 @@ import org.slf4j.LoggerFactory;
 
 /**
  * @author Greg Luck
- * @version $Id: RMIBootstrapCacheLoaderTest.java 4925 2011-11-04 18:06:28Z cdennis $
+ * @version $Id: RMIBootstrapCacheLoaderTest.java 6496 2012-10-31 14:34:15Z cdennis $
  */
 public class RMIBootstrapCacheLoaderTest extends AbstractRMITest {
 
@@ -73,23 +77,6 @@ public class RMIBootstrapCacheLoaderTest extends AbstractRMITest {
      * CacheManager 3 in the cluster
      */
     protected CacheManager manager3;
-    /**
-     * CacheManager 4 in the cluster
-     */
-    protected CacheManager manager4;
-    /**
-     * CacheManager 5 in the cluster
-     */
-    protected CacheManager manager5;
-    /**
-     * CacheManager 6 in the cluster
-     */
-    protected CacheManager manager6;
-
-    /**
-     * The name of the cache under test
-     */
-    protected String cacheName = "sampleCache1";
 
     /**
      * {@inheritDoc}
@@ -99,14 +86,16 @@ public class RMIBootstrapCacheLoaderTest extends AbstractRMITest {
      */
     @Before
     public void setUp() throws Exception {
+        List<Configuration> configurations = new ArrayList<Configuration>();
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed1.xml").name("cm1"));
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed2.xml").name("cm2"));
 
-        MulticastKeepaliveHeartbeatSender.setHeartBeatInterval(1000);
-
-        manager1 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed1.xml").name("cm1"));
-        manager2 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed2.xml").name("cm2"));;
+        List<CacheManager> managers = startupManagers(configurations);
+        manager1 = managers.get(0);
+        manager2 = managers.get(1);
 
         //allow cluster to be established
-        waitForClusterMembership(10, TimeUnit.SECONDS, Collections.singleton("sampleCache1"), manager1, manager2);
+        waitForClusterMembership(10, TimeUnit.SECONDS, Arrays.asList("sampleCache1", "sampleCache2"), manager1, manager2);
     }
 
     /**
@@ -142,15 +131,6 @@ public class RMIBootstrapCacheLoaderTest extends AbstractRMITest {
         if (manager3 != null) {
             manager3.shutdown();
         }
-        if (manager4 != null) {
-            manager4.shutdown();
-        }
-        if (manager5 != null) {
-            manager5.shutdown();
-        }
-        if (manager6 != null) {
-            manager6.shutdown();
-        }
 
         RetryAssert.assertBy(30, TimeUnit.SECONDS, new Callable<Set<Thread>>() {
             public Set<Thread> call() throws Exception {
