@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -23,8 +23,10 @@ import net.sf.ehcache.CacheManager;
 import net.sf.ehcache.Ehcache;
 import net.sf.ehcache.Element;
 import net.sf.ehcache.Status;
+import net.sf.ehcache.config.Configuration;
 import net.sf.ehcache.event.CacheEventListener;
 
+import org.hamcrest.core.DescribedAs;
 import org.junit.After;
 
 import static net.sf.ehcache.util.RetryAssert.assertBy;
@@ -40,9 +42,11 @@ import org.junit.Test;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.TimeUnit;
+import java.util.logging.Logger;
 
 /**
  * Unit tests for the RMICacheManagerPeerListener
@@ -50,10 +54,12 @@ import java.util.concurrent.TimeUnit;
  * Note these tests need a live network interface running in multicast mode to work
  *
  * @author <a href="mailto:gluck@thoughtworks.com">Greg Luck</a>
- * @version $Id: RMICacheManagerPeerListenerTest.java 4849 2011-10-17 17:08:47Z cdennis $
+ * @version $Id: RMICacheManagerPeerListenerTest.java 6496 2012-10-31 14:34:15Z cdennis $
  */
 public class RMICacheManagerPeerListenerTest extends AbstractRMITest {
 
+    private static final Logger LOGGER = Logger.getLogger(RMICacheManagerPeerListenerTest.class.getName());
+
     /**
      * CacheManager 1 in the cluster
      */
@@ -101,23 +107,41 @@ public class RMICacheManagerPeerListenerTest extends AbstractRMITest {
      */
     @Before
     public void setUp() throws Exception {
-        manager1 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed1.xml").name("cm1"));
-        manager2 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed2.xml").name("cm2"));
-        manager3 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed3.xml").name("cm3"));
-        manager4 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed4.xml").name("cm4"));
-        manager5 = new CacheManager(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed5.xml").name("cm5"));
+        List<Configuration> configurations = new ArrayList<Configuration>();
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed1.xml").name("cm1"));
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed2.xml").name("cm2"));
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed3.xml").name("cm3"));
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed4.xml").name("cm4"));
+        configurations.add(getConfiguration(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed5.xml").name("cm5"));
+
+        List<CacheManager> managers = startupManagers(configurations);
+        manager1 = managers.get(0);
+        manager2 = managers.get(1);
+        manager3 = managers.get(2);
+        manager4 = managers.get(3);
+        manager5 = managers.get(4);
 
         //allow cluster to be established
+        LOGGER.info("Validating Cluster Membership");
         waitForClusterMembership(10, TimeUnit.SECONDS, Collections.singleton(cacheName), manager1, manager2, manager3, manager4, manager5);
+        LOGGER.info("Validated Cluster Membership");
 
+        LOGGER.info("Putting Setup Value");
         manager1.getCache(cacheName).put(new Element("setup", "setup"));
+        LOGGER.info("Put Setup Value");
         for (CacheManager manager : new CacheManager[] {manager1, manager2, manager3, manager4, manager5}) {
-            assertBy(10, TimeUnit.SECONDS, elementAt(manager.getCache(cacheName), "setup"), notNullValue());
+            LOGGER.info("Validating Setup Value Propagation To " + manager);
+            assertBy(10, TimeUnit.SECONDS, elementAt(manager.getCache(cacheName), "setup"), DescribedAs.describedAs("Failed to propagate setup value to {}", notNullValue(), manager));
+            LOGGER.info("Validated Setup Value Propagation To " + manager);
         }
 
+        LOGGER.info("Performing RemoveAll");
         manager1.getCache(cacheName).removeAll();
+        LOGGER.info("Performed RemoveAll");
         for (CacheManager manager : new CacheManager[] {manager1, manager2, manager3, manager4, manager5}) {
-            assertBy(10, TimeUnit.SECONDS, sizeOf(manager.getCache(cacheName)), is(0));
+            LOGGER.info("Validating RemoveAll Propagation To " + manager);
+            assertBy(10, TimeUnit.SECONDS, sizeOf(manager.getCache(cacheName)), DescribedAs.describedAs("Failed to propagate removeAll to {}" , is(0), manager));
+            LOGGER.info("Validated RemoveAll Propagation To " + manager);
         }
 
         cache1 = manager1.getCache(cacheName);
@@ -296,26 +320,4 @@ public class RMICacheManagerPeerListenerTest extends AbstractRMITest {
 
     }
 
-    /**
-     * Does the RMI listener stop?
-     * <p/>
-     * This test does not actually do test the shutdown hook automatically. But you should be able to
-     * see "VM shutting down with the RMICacheManagerPeerListener for localhost still active. Calling dispose..."
-     * in the log with FINE level when this test is run individually or as the last test in the run. i.e. on VM shutdown.
-     */
-    @Test
-    public void testListenerShutsdownFromShutdownHook() {
-        CacheManager manager = new CacheManager(AbstractCacheTest.TEST_CONFIG_DIR + "distribution/ehcache-distributed6.xml");
-        try {
-            CacheManagerPeerListener cachePeerListener = manager.getCachePeerListener("RMI");
-            List cachePeers1 = cachePeerListener.getBoundCachePeers();
-            assertEquals(55, cachePeers1.size());
-            assertEquals(Status.STATUS_ALIVE, cachePeerListener.getStatus());
-        } finally {
-            /*
-             * This test intentionally doesn't call shutdown - the VM should do it for us.
-             */
-            //manager.shutdown();
-        }
-    }
 }
