@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -42,6 +42,7 @@ import java.util.List;
 import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
+import net.sf.ehcache.distribution.RmiEventMessage.RmiEventType;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -52,7 +53,7 @@ import org.slf4j.LoggerFactory;
  * Note these tests need a live network interface running in multicast mode to work
  *
  * @author <a href="mailto:gluck@thoughtworks.com">Greg Luck</a>
- * @version $Id: RMICacheManagerPeerTest.java 4248 2011-06-30 20:37:18Z cdennis $
+ * @version $Id: RMICacheManagerPeerTest.java 5959 2012-07-11 16:49:27Z cdennis $
  */
 public class RMICacheManagerPeerTest extends AbstractRMITest {
 
@@ -64,7 +65,7 @@ public class RMICacheManagerPeerTest extends AbstractRMITest {
      */
     protected CacheManager manager;
     private final String hostName = "localhost";
-    private final Integer port = Integer.valueOf(40000);
+    private final Integer port = Integer.valueOf(5010);
     private RMICacheManagerPeerListener peerListener;
     private Cache cache;
 
@@ -184,7 +185,7 @@ public class RMICacheManagerPeerTest extends AbstractRMITest {
 
         CachePeer cachePeer = new ManualRMICacheManagerPeerProvider().lookupRemoteCachePeer(rmiCachePeer.getUrl());
         Element element = new Element("1", new Date());
-        EventMessage eventMessage = new EventMessage(EventMessage.PUT, null, element);
+        RmiEventMessage eventMessage = new RmiEventMessage(null, RmiEventType.PUT, null, element);
         List eventMessages = new ArrayList();
         eventMessages.add(eventMessage);
         cachePeer.send(eventMessages);
