@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -27,6 +27,7 @@ import static net.sf.ehcache.event.CountingCacheEventListener.getCountingCacheEv
 import net.sf.ehcache.store.disk.DiskStoreHelper;
 
 import static org.hamcrest.CoreMatchers.equalTo;
+import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.core.IsNull.nullValue;
 import static org.hamcrest.collection.IsCollectionWithSize.hasSize;
 import static org.hamcrest.number.OrderingComparison.greaterThanOrEqualTo;
@@ -45,6 +46,7 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
+import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -58,7 +60,7 @@ import org.slf4j.LoggerFactory;
  * Tests the cache listener functionality
  *
  * @author Greg Luck
- * @version $Id: CacheEventListenerTest.java 4877 2011-10-24 16:52:42Z cdennis $
+ * @version $Id: CacheEventListenerTest.java 6860 2013-01-14 16:04:17Z alexsnaps $
  */
 public class CacheEventListenerTest extends AbstractCacheTest {
 
@@ -729,15 +731,12 @@ public class CacheEventListenerTest extends AbstractCacheTest {
         }
 
         // Wait for expiry and expiry thread
-        Thread.sleep(6999);
-
-        CountingCacheEventListener listener = getCountingCacheEventListener(cache);
-        List<CacheEvent> notifications = listener.getCacheElementsExpired();
-        for (int i = 0; i < notifications.size(); i++) {
-            Element element = notifications.get(i).getElement();
-            element.getObjectKey();
-        }
-        assertThat(notifications, hasSize(20));
+        RetryAssert.assertBy(15, TimeUnit.SECONDS, new Callable<List<CacheEvent>>() {
+            @Override
+            public List<CacheEvent> call() throws Exception {
+                return getCountingCacheEventListener(cache).getCacheElementsExpired();
+            }
+        }, hasSize(20));
     }
 
 
