@@ -3,6 +3,7 @@ package net.sf.ehcache.event;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
+import static org.hamcrest.Matchers.greaterThan;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertThat;
 import static org.junit.Assert.fail;
@@ -13,6 +14,7 @@ import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.logging.Filter;
 import java.util.logging.LogRecord;
@@ -53,7 +55,7 @@ public class EvictionListenerTest {
     @BeforeClass
     public static void createCacheManager() {
         Configuration configuration = new Configuration();
-        configuration.diskStore(new DiskStoreConfiguration().path("./target/tmp/"));
+        configuration.diskStore(new DiskStoreConfiguration().path("./target/tmp/")).name(EvictionListenerTest.class.getSimpleName());
         cacheManager = new CacheManager(configuration);
         Logger.getLogger(DiskStorageFactory.class.getName()).setFilter(new Filter() {
             public boolean isLoggable(LogRecord lr) {
@@ -80,7 +82,6 @@ public class EvictionListenerTest {
             cache.put(new Element("key" + i, UUID.randomUUID().toString()));
         }
         DiskStoreHelper.flushAllEntriesToDisk(cache).get();
-        assertThat(cache.getMemoryStoreSize(), is(100L));
         final int diskStoreSize = cache.getDiskStoreSize();
         Map<Object, AtomicInteger> cacheElementsEvicted = countingCacheEventListener.getCacheElementsEvicted(cache);
         System.out.println("\n\n ****");
@@ -163,7 +164,6 @@ public class EvictionListenerTest {
     public void testGetsAllEvictedKeys() throws InterruptedException, ExecutionException {
         CountingCacheEventListener countingCacheEventListener = accessCache(cache);
         DiskStoreHelper.flushAllEntriesToDisk(cache).get();
-        assertThat(cache.getMemoryStoreSize(), is(100L));
         Map<Object, AtomicInteger> cacheElementsEvicted = countingCacheEventListener.getCacheElementsEvicted(cache);
         for (Map.Entry<Object, AtomicInteger> entry : cacheElementsEvicted.entrySet()) {
             assertThat("Evicted multiple times: " + entry.getKey(), entry.getValue().get(), equalTo(1));
@@ -241,6 +241,30 @@ public class EvictionListenerTest {
         assertThat(cacheElementsEvicted.size() + diskCache.getSize(), is(THREADS * PER_THREAD));
     }
 
+    @Test
+    public void testGetsAllEvictedKeysWithDiskPersistentEntryBased() throws InterruptedException, ExecutionException {
+        cache = new Cache(new CacheConfiguration("testGetsAllEvictedKeysWithDiskPersistentEntryBased", 100)
+            .maxEntriesLocalDisk(2000)
+            .eternal(true)
+            .diskPersistent(true));
+        cacheManager.addCache(cache);
+        CountingCacheEventListener countingCacheEventListener = accessCache(cache);
+        DiskStoreHelper.flushAllEntriesToDisk(cache).get();
+        Map<Object, AtomicInteger> cacheElementsEvicted = countingCacheEventListener.getCacheElementsEvicted(cache);
+//        for (Map.Entry<Object, AtomicInteger> entry : cacheElementsEvicted.entrySet()) {
+//            assertThat("Evicted multiple times: " + entry.getKey(), entry.getValue().get(), equalTo(1));
+//        }
+
+        DiskStoreHelper.flushAllEntriesToDisk(cache).get(); // Make sure all is flushed...
+        final int cacheSize = cache.getSize();
+        final int evictedElementCount = cacheElementsEvicted.size();
+
+        assertThat(cacheSize, greaterThan(0));
+        assertThat(evictedElementCount, greaterThan(0));
+        System.out.println(cacheSize);
+        assertThat(evictedElementCount + cacheSize, is(THREADS * PER_THREAD));
+    }
+
     private CountingCacheEventListener accessCache(final Cache cacheUT) throws InterruptedException {
         CountingCacheEventListener countingCacheEventListener = new CountingCacheEventListener();
         cacheUT.getCacheEventNotificationService().registerListener(countingCacheEventListener);
@@ -326,7 +350,14 @@ public class EvictionListenerTest {
     }
 
     @After
-    public void tearDown() {
+    public void tearDown() throws ExecutionException, InterruptedException {
+        if(cache != null) {
+            cache.removeAll();
+            final Future<Void> future = DiskStoreHelper.flushAllEntriesToDisk(cache);
+            if(future != null) {
+                future.get();
+            }
+        }
         cacheManager.removalAll();
     }
 
