@@ -1,5 +1,5 @@
 /**
- *  Copyright 2003-2010 Terracotta, Inc.
+ *  Copyright Terracotta, Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -28,6 +28,9 @@ import org.hibernate.cfg.Environment;
 import org.junit.After;
 
 import static java.util.concurrent.TimeUnit.SECONDS;
+import static org.hamcrest.number.OrderingComparison.greaterThan;
+import static org.hamcrest.number.OrderingComparison.lessThan;
+import static org.hamcrest.number.OrderingComparison.lessThanOrEqualTo;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertThat;
@@ -50,7 +53,7 @@ import org.slf4j.LoggerFactory;
  * Tests for a Cache
  *
  * @author Greg Luck, Claus Ibsen
- * @version $Id: HibernateAPIUsageTest.java 4670 2011-09-09 22:46:40Z alexsnaps $
+ * @version $Id: HibernateAPIUsageTest.java 5943 2012-07-10 16:42:48Z alexsnaps $
  */
 public class HibernateAPIUsageTest extends AbstractCacheTest {
     private static final Logger LOG = LoggerFactory.getLogger(HibernateAPIUsageTest.class.getName());
@@ -131,12 +134,13 @@ public class HibernateAPIUsageTest extends AbstractCacheTest {
         }
         Thread.sleep(100);
         //this is now fixed
-        assertEquals(10000, cache.getElementCountInMemory());
+        assertThat(cache.getElementCountInMemory(), lessThanOrEqualTo(10000L));
         RetryAssert.assertBy(1, SECONDS, new Callable<Long>() {
             public Long call() throws Exception {
                 return cache.getElementCountOnDisk();
             }
-        }, Is.is(1000L));
+        }, lessThan(1002L));
+        assertThat(cache.getElementCountOnDisk(), greaterThan(999L));
 
         //clear
         cache.clear();
@@ -362,7 +366,7 @@ public class HibernateAPIUsageTest extends AbstractCacheTest {
             //expected
         }
 
-        ((net.sf.ehcache.hibernate.EhCache) cache).getBackingCache().getCacheManager().shutdown();
+        provider.stop();
 
 
     }
@@ -537,7 +541,8 @@ public class HibernateAPIUsageTest extends AbstractCacheTest {
             //expected
         }
 
-        ((net.sf.ehcache.hibernate.EhCache) cache).getBackingCache().getCacheManager().shutdown();
+        provider.stop();
+        provider2.stop();
     }
 
     /**
